@@ -1,11 +1,10 @@
-{-# OPTIONS_GHC -fno-warn-orphans #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Text.Regex.Posix.Sequence
 -- Copyright   :  (c) Chris Kuklewicz 2006
 -- License     :  BSD-3-Clause
 --
--- Maintainer  :  hvr@gnu.org, Andreas Abel
+-- Maintainer  :  Andreas Abel
 -- Stability   :  stable
 -- Portability :  non-portable (regex-base needs MPTC+FD)
 --
@@ -48,7 +47,16 @@ module Text.Regex.Posix.Sequence(
   execNotEOL     -- not at end of line
   ) where
 
-import Prelude hiding (fail)
+import Prelude
+  ( Char
+  , Int, (-), fromEnum, fromIntegral, pred
+  , Show(show)
+  , Either(Left, Right), either
+  , IO, (>>), (>>=), return
+  , Maybe(Nothing, Just)
+  , ($), (.), (==), otherwise
+  , (++), length, map
+  )
 import Control.Monad.Fail (MonadFail(fail))
 
 import Data.Array(listArray, Array)
@@ -114,7 +122,7 @@ execute regex str = do
   maybeStartEnd <- withSeq str (wrapMatch regex)
   case maybeStartEnd of
     Right Nothing -> return (Right Nothing)
---  Right (Just []) ->  fail "got [] back!" -- return wierd array instead
+--  Right (Just []) ->  fail "got [] back!" -- return weird array instead
     Right (Just parts) ->
       return . Right . Just . listArray (0,pred (length parts))
        . map (\(s,e)->(fromIntegral s, fromIntegral (e-s)))
